@@ -1,9 +1,12 @@
 import os, sys, tarfile
 from shutil import copyfile
 from google.cloud import storage
+from google.cloud.exceptions import NotFound
+from cloud_storage_client.exceptions import NotFoundException
 
 CHUNK_SIZE = 10485760
 
+
 class GCloudStorageClient():
     """
     Google Cloud Storage Client to connect with Goocle Cloud Storage
@@ -38,7 +41,7 @@ class GCloudStorageClient():
     def download_folder(self, src_folder, dst_folder):
         bucket = self.client.get_bucket(self.bucket_name)
         if src_folder[0] == '/':
-            foldersrc_folder_id = src_folder[1:len(src_folder)]
+            src_folder = src_folder[1:len(src_folder)]
         blobs = bucket.list_blobs(prefix=src_folder)
 
         for blob in blobs:
@@ -46,20 +49,44 @@ class GCloudStorageClient():
                 if not os.path.exists(dst_folder):
                     os.makedirs(dst_folder)
                 splitted_name = blob.name.split('/')
+                splitted_name = list(filter(None, splitted_name))
                 blob.download_to_filename(dst_folder + '/' + splitted_name[len(splitted_name) - 1])
 
-    def upload_file(self, src_file, dst_file):
-        bucket = self.client.get_bucket(self.bucket_name)
-        if dst_file[0] == '/':
-            dst_file = dst_file[1:len(dst_file)]
-        blob = bucket.blob(dst_file, chunk_size=CHUNK_SIZE)
-        blob.cache_control = 'public, max-age=2'
-        blob.upload_from_filename(filename=src_file)
+    def _get_content_type(self, dst_file):
+        if dst_file.endswidth('/Manifest') or dst_file.endswidth('.ismc') or dst_file == 'Manifest':
+            content_settings = 'text/xml'
+        elif dst_file.endswidth('.m3u8'):
+            content_settings = 'application/x-mpegURL'
+        elif dst_file.endswidth('.mpd'):
+            content_settings = 'application/dash+xml'
+        else:
+            content_settings = None
+
+        return content_settings
+
+    def upload_file(self, src_file, dst_file, options):
+        try:
+            bucket = self.client.get_bucket(self.bucket_name)
+            if dst_file[0] == '/':
+                dst_file = dst_file[1:len(dst_file)]
+            if dst_file[-1] == '/':
+                dst_file = dst_file[0:len(dst_file) - 1]
+            dst_file = dst_file.replace('//', '/')
+
+            blob = bucket.blob(dst_file, chunk_size=CHUNK_SIZE)
+            blob.cache_control = 'public, max-age=2'
+            blob.upload_from_filename(filename=src_file, content_type=self._get_content_type(dst_file))
+        except NotFound as notFoundError:
+            raise NotFoundException(notFoundError)
 
     def upload_files(self, folder_id, selected_chunks, folder_chunks, do_tar=False, do_compress=False):
         bucket = self.client.get_bucket(self.bucket_name)
         if folder_id[0] == '/':
             folder_id = folder_id[1:len(folder_id)]
+        if folder_id[-1] == '/':
+            folder_id = folder_id[0:len(folder_id) - 1]
+        folder_id = folder_id.replace('//', '/')
+
         if do_tar:
             if do_compress:
                 ext = '.tgz'
@@ -83,11 +110,11 @@ class GCloudStorageClient():
             for chunk in selected_chunks:
                 blob = bucket.blob(folder_id + '/' + chunk, chunk_size=CHUNK_SIZE)
                 blob.cache_control = 'public, max-age=2'
-                blob.upload_from_filename(filename=folder_chunks + '/' + chunk)
+                blob.upload_from_filename(filename=folder_chunks + '/' + chunk, content_type=self._get_content_type(chunk))
 
     def download_file(self, folder_id, selected_chunk, output_folder):
         bucket = self.client.get_bucket(self.bucket_name)
-        if folder_id == '':
+        if folder_id == '' or folder_id == '/':
             file_path = selected_chunk
         else:
             file_path = folder_id + '/' + selected_chunk
@@ -97,6 +124,7 @@ class GCloudStorageClient():
         if not os.path.exists(output_folder):
             os.makedirs(output_folder)
         splitted_name = blob.name.split('/')
+        splitted_name = list(filter(None, splitted_name))
         blob.download_to_filename(output_folder + '/' + splitted_name[len(splitted_name) - 1])
 
     def upload_folder(self, dst_folder, src_folder, do_tar=False, do_compress=False):
@@ -130,7 +158,7 @@ class GCloudStorageClient():
                 if not os.path.isdir(filePath):
                     blob = bucket.blob(dst_folder + '/' + file.decode('utf-8'), chunk_size=CHUNK_SIZE)
                     blob.cache_control = 'public, max-age=2'
-                    blob.upload_from_filename(filename=filePath)
+                    blob.upload_from_filename(filename=filePath, content_type=self._get_content_type(filePath))
 
     def list_files_folder(self, folder):
         bucket = self.client.get_bucket(self.bucket_name)
@@ -138,3 +166,8 @@ class GCloudStorageClient():
             folder = folder[1:len(folder)]
         return [blob.name for blob in bucket.list_blobs(prefix=folder) if blob.name.find(folder + '/') == 0]
 
+    def get_file_size(self, filename):
+        try:
+            return self.client.get_bucket(self.bucket_name).get_blob(filename.ltrim('/')).size
+        except:
+            return -1
\ No newline at end of file
